@@ -1,6 +1,6 @@
 package CHI::Driver::Role::HasSubcaches;
 BEGIN {
-  $CHI::Driver::Role::HasSubcaches::VERSION = '0.49';
+  $CHI::Driver::Role::HasSubcaches::VERSION = '0.50';
 }
 use Moose::Role;
 use Hash::MoreUtils qw(slice_exists);
@@ -75,7 +75,7 @@ sub add_subcache {
 
 # Call these methods first on the main cache, then on any subcaches.
 #
-foreach my $method (qw(clear expire purge remove)) {
+foreach my $method (qw(clear expire purge remove set)) {
     after $method => sub {
         my $self      = shift;
         my $subcaches = $self->subcaches;
@@ -85,22 +85,6 @@ foreach my $method (qw(clear expire purge remove)) {
     };
 }
 
-after 'set_object' => sub {
-    my ( $self, $key, $obj ) = @_;
-
-    my $subcaches = $self->subcaches;
-    foreach my $subcache (@$subcaches) {
-        $subcache->set(
-            $key,
-            $obj->value,
-            {
-                expires_at       => $obj->expires_at,
-                early_expires_at => $obj->early_expires_at
-            }
-        );
-    }
-};
-
 around 'get' => sub {
     my $orig = shift;
     my $self = shift;
