@@ -1,6 +1,6 @@
 package CHI::t::Driver::Subcache::mirror_cache;
 BEGIN {
-  $CHI::t::Driver::Subcache::mirror_cache::VERSION = '0.49';
+  $CHI::t::Driver::Subcache::mirror_cache::VERSION = '0.50';
 }
 use strict;
 use warnings;
@@ -27,4 +27,7 @@ sub new_cache_options {
     );
 }
 
+# This tries to create its own mirror cache
+sub test_max_key_length { }
+
 1;
